@@ -79,7 +79,7 @@ void KNSReviews::fetchReviews(AbstractResource* app, int page)
     Attica::ListJob< Attica::Comment >* job =
         provider().requestComments(Attica::Comment::ContentComment, app->packageName(), QStringLiteral("0"), page, 10);
     if (!job) {
-        emit reviewsReady(app, {});
+        emit reviewsReady(app, {}, false);
         return;
     }
     job->setProperty("app", qVariantFromValue<AbstractResource*>(app));
@@ -91,18 +91,18 @@ void KNSReviews::commentsReceived(Attica::BaseJob* j)
 {
     Attica::ListJob<Attica::Comment>* job = static_cast<Attica::ListJob<Attica::Comment>*>(j);
     Attica::Comment::List comments = job->itemList();
-    
-    QList<Review*> reviews;
+
+    QVector<ReviewPtr> reviews;
     AbstractResource* app = job->property("app").value<AbstractResource*>();
     foreach(const Attica::Comment& comment, comments) {
         //TODO: language lookup?
-        Review* r = new Review(app->name(), app->packageName(), QStringLiteral("en"), comment.subject(), comment.text(), comment.user(),
+        ReviewPtr r(new Review(app->name(), app->packageName(), QStringLiteral("en"), comment.subject(), comment.text(), comment.user(),
             comment.date(), true, comment.id().toInt(), comment.score()/10, 0, 0, QString()
-        );
+        ));
         reviews += r;
     }
-    
-    emit reviewsReady(app, reviews);
+
+    emit reviewsReady(app, reviews, !reviews.isEmpty());
 }
 
 bool KNSReviews::isFetching() const
@@ -183,4 +183,9 @@ Attica::Provider KNSReviews::provider() const
     return s_shared->atticaManager.providerFor(m_providerUrl);
 }
 
+bool KNSReviews::isResourceSupported(AbstractResource* res) const
+{
+    return qobject_cast<KNSResource*>(res);
+}
+
 #include "KNSReviews.moc"
