@@ -22,6 +22,7 @@
 
 #include "AbstractResource.h"
 #include "resources/AbstractResourcesBackend.h"
+#include "resources/AbstractBackendUpdater.h"
 #include <ReviewsBackend/Rating.h>
 #include <ReviewsBackend/AbstractReviewsBackend.h>
 #include <Transaction/Transaction.h>
@@ -34,6 +35,7 @@
 #include <QThread>
 #include <QAction>
 #include <QMetaProperty>
+#include <KLocalizedString>
 
 ResourcesModel *ResourcesModel::s_self = nullptr;
 
@@ -60,6 +62,18 @@ void ResourcesModel::init(bool load)
 
     if(load)
         QMetaObject::invokeMethod(this, "registerAllBackends", Qt::QueuedConnection);
+
+
+    QAction* updateAction = new QAction(this);
+    updateAction->setIcon(QIcon::fromTheme(QStringLiteral("system-software-update")));
+    updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
+    updateAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
+    connect(this, &ResourcesModel::fetchingChanged, updateAction, [updateAction, this](){
+        updateAction->setEnabled(!isFetching());
+    });
+    connect(updateAction, &QAction::triggered, this, &ResourcesModel::checkForUpdates);
+
+    m_ownActions += updateAction;
 }
 
 ResourcesModel::ResourcesModel(const QString& backendName, QObject* parent)
@@ -100,6 +114,7 @@ void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
     connect(backend, &AbstractResourcesBackend::updatesCountChanged, this, &ResourcesModel::updatesCountChanged);
     connect(backend, &AbstractResourcesBackend::resourceRemoved, this, &ResourcesModel::resourceRemoved);
     connect(backend, &AbstractResourcesBackend::passiveMessage, this, &ResourcesModel::passiveMessage);
+    connect(backend->backendUpdater(), &AbstractBackendUpdater::progressingChanged, this, &ResourcesModel::fetchingChanged);
 
     if(m_initializingBackends==0)
         emit allInitialized();
@@ -208,15 +223,20 @@ void ResourcesModel::integrateActions(KActionCollection* w)
 bool ResourcesModel::isFetching() const
 {
     foreach(AbstractResourcesBackend* b, m_backends) {
-        if(b->isFetching())
+        // isFetching should sort of be enough. However, sometimes the backend itself
+        // will still be operating on things, which from a model point of view would
+        // still mean something going on. So, interpret that as fetching as well, for
+        // the purposes of this property.
+        if(b->isFetching() || (b->backendUpdater() && b->backendUpdater()->isProgressing())) {
             return true;
+        }
     }
     return false;
 }
 
 QList<QAction*> ResourcesModel::messageActions() const
 {
-    QList<QAction*> ret;
+    QList<QAction*> ret = m_ownActions;
     foreach(AbstractResourcesBackend* b, m_backends) {
         ret += b->messageActions();
     }
@@ -314,3 +334,9 @@ AbstractResource* ResourcesModel::resourceForFile(const QUrl& file)
     }
     return ret;
 }
+
+void ResourcesModel::checkForUpdates()
+{
+    for(auto backend: qAsConst(m_backends))
+        backend->checkForUpdates();
+}
